aboutsummaryrefslogtreecommitdiffstats
path: root/params
diff options
context:
space:
mode:
authorPéter Szilágyi <peterke@gmail.com>2016-07-08 18:00:37 +0800
committerPéter Szilágyi <peterke@gmail.com>2016-07-15 21:52:55 +0800
commit1e24c2e4f428c85c2f83272af2696469cb8f5bed (patch)
tree8939d4ddee2b093f01ed656b1603c8d3efc76706 /params
parent9e56811a3773e225bedf6bf0003327ea1aaae040 (diff)
downloadgo-tangerine-1e24c2e4f428c85c2f83272af2696469cb8f5bed.tar
go-tangerine-1e24c2e4f428c85c2f83272af2696469cb8f5bed.tar.gz
go-tangerine-1e24c2e4f428c85c2f83272af2696469cb8f5bed.tar.bz2
go-tangerine-1e24c2e4f428c85c2f83272af2696469cb8f5bed.tar.lz
go-tangerine-1e24c2e4f428c85c2f83272af2696469cb8f5bed.tar.xz
go-tangerine-1e24c2e4f428c85c2f83272af2696469cb8f5bed.tar.zst
go-tangerine-1e24c2e4f428c85c2f83272af2696469cb8f5bed.zip
cmd/geth, miner, params: special extradata for DAO fork start
Diffstat (limited to 'params')
-rw-r--r--params/util.go17
1 files changed, 12 insertions, 5 deletions
diff --git a/params/util.go b/params/util.go
index b76850852..a0c9a3199 100644
--- a/params/util.go
+++ b/params/util.go
@@ -16,11 +16,18 @@
package params
-import "math/big"
+import (
+ "math/big"
+
+ "github.com/ethereum/go-ethereum/common"
+)
var (
- TestNetHomesteadBlock = big.NewInt(494000) // testnet homestead block
- MainNetHomesteadBlock = big.NewInt(1150000) // mainnet homestead block
- TestNetDAOForkBlock = big.NewInt(8888888) // testnet dao hard-fork block
- MainNetDAOForkBlock = big.NewInt(9999999) // mainnet dao hard-fork block
+ TestNetHomesteadBlock = big.NewInt(494000) // Testnet homestead block
+ MainNetHomesteadBlock = big.NewInt(1150000) // Mainnet homestead block
+
+ TestNetDAOForkBlock = big.NewInt(8888888) // Testnet dao hard-fork block
+ MainNetDAOForkBlock = big.NewInt(9999999) // Mainnet dao hard-fork block
+ DAOForkBlockExtra = common.FromHex("0x64616f2d686172642d666f726b") // Block extradata to signel the fork with ("dao-hard-fork")
+ DAOForkExtraRange = big.NewInt(10) // Number of blocks to override the extradata (prevent no-fork attacks)
)